@@ -11,6 +11,7 @@ def main():
     parser.add_argument('command', type=str, nargs='+')
 
     command = parser.parse_args().command
+
     if command[0] == 'init':
         init()
 
@@ -27,7 +28,7 @@ def main():
             print('Invalid git hook type.')
             return
 
-        run_hook(command[1])
+        run_hook(command[1:])
     else:
         print("Unrecognized ocommand.")
 
